@@ -61,16 +61,14 @@ async def get_db_path(url: URL, referer=None):
     """Gets the URL path to be put into the DB and checked from the DB"""
     url_path = url.path
     if 'anonfiles' in url.host or 'bayfiles' in url.host:
-        url_path = url.path
         url_path = url_path.split('/')
         url_path.pop(0)
         if len(url_path) > 1:
             url_path.pop(1)
         url_path = '/' + '/'.join(url_path)
-    if referer:
-        if "e-hentai" in referer:
-            url_path = url.path
-            url_path = url_path.split('keystamp')[0][:-1]
+
+    if referer and "e-hentai" in referer:
+        url_path = url_path.split('keystamp')[0][:-1]
 
     return url_path
 
@@ -91,8 +89,8 @@ async def check_direct(url: URL):
     """Checks whether the given url is a direct link to a content item"""
     mapping_direct = [r'i.pixl.li', r'i..pixl.li', r'img-...cyberdrop...', r'f.cyberdrop...',
                       r'fs-...cyberdrop...', r'jpg.church/images/...', r'simp..jpg.church', r's..putmega.com',
-                      r's..putme.ga', r'images..imgbox.com', 's..lovefap...']
-    return any(re.search(domain, url.host) for domain in mapping_direct)
+                      r's..putme.ga', r'images..imgbox.com', r's..lovefap...', r'img.kiwi/images/']
+    return any(re.search(domain, str(url)) for domain in mapping_direct)
 
 
 async def get_filename_and_ext(filename, forum=False):
