@@ -77,7 +77,6 @@ class ScrapeMapper:
         self.jdownloader = JDownloader(args['JDownloader'], quiet)
 
         self.jpgfish_limiter = AsyncRateLimiter(10)
-        self.img_kiwi_limiter = AsyncRateLimiter(5)
         self.bunkr_limiter = AsyncRateLimiter(15)
         self.coomeno_limiter = AsyncRateLimiter(8)
         self.gofile_limiter = AsyncRateLimiter(max_calls=1, period=2)
@@ -96,7 +95,7 @@ class ScrapeMapper:
                         "postimg": self.PostImg, "saint": self.Saint, "img.kiwi": self.ShareX,
                         "jpg.church": self.ShareX, "jpg.fish": self.ShareX, "pixl.li": self.ShareX,
                         "nsfw.xxx": self.NSFW_XXX, "pimpandhost": self.PimpAndHost, "lovefap": self.LoveFap,
-                        "e-hentai": self.EHentai, "gallery.deltaporno": self.ShareX,
+                        "e-hentai": self.EHentai, "gallery.deltaporno": self.ShareX, "vk.com": self.vk_redirect,
                         "coomer.party": self.Coomeno, "kemono.party": self.Coomeno,
                         "simpcity": self.Xenforo, "socialmediagirls": self.Xenforo, "xbunker": self.Xenforo}
 
@@ -116,6 +115,12 @@ class ScrapeMapper:
                 for title, album in domain_obj.albums.items():
                     await self.Cascade.add_album(domain, album.title, album)
 
+    """Redirection handler for Simp City"""
+
+    async def vk_redirect(self, url: URL, title=None):
+        url = URL(url.query['to'])
+        await self.map_url(url, title)
+
     """Regular file host handling"""
 
     async def Anonfiles(self, url: URL, title=None):
@@ -253,9 +258,6 @@ class ScrapeMapper:
             async with self.jpgfish_semaphore:
                 async with self.jpgfish_limiter:
                     domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
-        elif "img.kiwi" in url.host and sharex_session.client.ratelimit > 5:
-            async with self.img_kiwi_limiter:
-                domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
         else:
             domain_obj = await self.sharex_crawler.fetch(sharex_session, url)
         await self.handle_additions("sharex", None, domain_obj, title)
